clear all

**************************************************************
***2019 IEADB article: Figures 1a and 1b (Rates of IEA signatures)
foreach selected_scheme in iea_color iea_bw {
	if "`selected_scheme'"=="iea_color" | "`selected_scheme'"=="iea_color_bar" { 
		local color "Color"
	}
	if "`selected_scheme'"=="iea_bw" | "`selected_scheme'"=="iea_bw_bar" { 
		local color "BW"
	}
	foreach include in BEA MEA {
		use iea.dta, clear
		keep if inclusion=="`include'"
		drop inclusion
		collapse (count) mitch_id, by(agreement_type tsig_yr)
		reshape wide mitch_id, i(tsig_yr) j(agreement_type) string
		ren mitch_id* *
		ren tsig_yr year
		tset year
		foreach x in Agreement Protocol Amendment {
				***next line replaces missing with zero, so averaging works properly
				replace `x'=0 if `x'==.
				gen `x'_5yravg=(F2.`x' + F1.`x' + `x' + L1.`x' + L2.`x')/5
				gen `x'_3yravg=(F1.`x' + `x' + L1.`x')/3
		}
		foreach y in 5 {
			label var Agreement_`y' "Agreements"
			label var Protocol_`y' "Protocols"
			label var Amendment_`y' "Amendments"
		***Need to set xlabel for number of ticks and angle within command, not in scheme: 
		***Example: xlabel(1950 (5) 2017, angle(70))
			line Agreement_`y' Protocol_`y' Amendment_`y' year if year>1945, xlabel(1950 (5) 2017, angle(70)) scheme(`selected_scheme') xtitle("") ytitle("5-year average") title("`include' Annual Signature Rate") graphregion(margin(tiny)) ysize(1) xsize(1.1) plotregion(margin(tiny))
			noisily di "Graph Filename=`include'_sigrate_`color'.png" 
			graph export "graphs\\`include'_sigrate_`color'.png", replace
		}
		**ysize(1) xsize(1.7) -- to control aspect ratio
	}
}


**************************************************************
***2019 IEADB article: Figures 2a and 2b (Figure 2.	Share of subjects covered by MEAs and BEAs) 
***     and Figure 3 (Subject emergence)
program graph_subject
	use iea.dta, clear
	args include selected_scheme bylineage dategrp i title 
	local graphparams "scheme(`selected_scheme') outergap(-20) stack nolabel bargap(-20) yscale(range(0 100) titlegap(5)) legend(order(8 7 6 5 4 3 2 1)) graphregion(margin(tiny)) ysize(1.1) xsize(1.9)"
	local startyear=1500
	local groupingvar="subj_code"
	local groupingvals="Species Pollution Freshwater Habitat Energy Climate Human_sphere Other"
	keep if subj_code!="" & inclusion=="`include'" & tsig_yr!=. & tsig_yr>`startyear' `bylineage'
	collapse (count) mitch_id, by(`groupingvar' tsigd_g)
	reshape wide mitch_id, i(tsigd) j(`groupingvar') string
	ren mitch_id* *
	foreach var of varlist _all {
		label var `var' "`var'"
	}

	***remove "percent" from next line if want count instead
	graph bar (sum) `groupingvals', `dategrp' title("`title'") ytitle("") `graphparams' percent 
end

foreach selected_scheme in iea_color_bar iea_bw_bar {
	if "`selected_scheme'"=="iea_color" | "`selected_scheme'"=="iea_color_bar" { 
		local color "Color"
	}
	if "`selected_scheme'"=="iea_bw" | "`selected_scheme'"=="iea_bw_bar" { 
		local color "BW"
	}
	foreach include in BEA MEA {
		graph_subject "`include'" "`selected_scheme'" "" "over(tsigd_g, gap(20) label(angle(70)))" "`i'" "Subjects of `include's (% share)" 
		noisily di "Graph Filename=Subject_Share_`include'_`color'.png" 
		graph export "graphs\\Subject_Share_`include'_`color'.png", replace
	}
	local include "MEA"
		graph_subject "`include'" "`selected_scheme'" "& lineagestarter!=." "over(tsigd_g, gap(20) label(angle(70)))" "`i'" "Subjects of First MEA in Lineages (% share)" 
		noisily di "Graph Filename=Subject_Emergence_`include'_`color'.png" 
		graph export "graphs\\Subject_Emergence_`include'_`color'.png", replace
}


****************************************************************************************************************************
***2019 IEADB article: Figure 4a and 4b (Average Size: Global and Non-Global MEA Agreements)
foreach selected_scheme in iea_color_bar iea_bw_bar {
	if "`selected_scheme'"=="iea_color" | "`selected_scheme'"=="iea_color_bar" { 
		local color "Color"
	}
	if "`selected_scheme'"=="iea_bw" | "`selected_scheme'"=="iea_bw_bar" { 
		local color "BW"
	}
	use iea-country.dta, clear
	keep if inclusion=="MEA" & agreement_type=="Agreement"
	local countyr=9
	local lastyr=2018-`countyr'
	local lastyr2=substr("`lastyr'",3,2)
	local lastyr1=2018-`countyr'+1
	*** next line drops int_org and reacquires to ensure accuracy of int_org info based on IEA not iea-country
	drop int_org
	merge m:1 mitch_id using io_elig_rules.dta, keep(matched master)
	***At this point, have all iea-country observations for the 452 MEAs identified in temp-id.dta 
	***Confirm that country formed before year 9 and hadn't dissolved before ceif3
	drop if country_formed>tsig+(365*`countyr')
	drop if country_dissolved<ceif3
	gen global="Global" if int_org=="United_Nations"
	replace global="Non_Global" if int_org!="United_Nations"

	***Now generate whether a member by year 9
	gen memb_in_yr`countyr'=1 if (ceif3-tsig)<=(365*`countyr')
	collapse (count) memb_in_yr9, by(mitch_id tsig global)
	gen year=year(tsig)
	drop tsig
	gen dec = 10 * floor(year/10) + 5
	replace dec = dec - 10 if year<dec
	gen dec1= string(dec)+"-"+substr(string(dec+9),3,2)
	replace dec1="<1945" if year<1945
	replace dec1="2005-`lastyr2'" if year>=2005
	label define decade 1 "<1945"  
	encode dec1, gen(decade)
	drop dec dec1
	drop if year>`lastyr'
	drop year
	reshape wide memb_in_yr9, i(mitch_id decade) j(global) string
	egen All = rowtotal(memb_in_yr9Global memb_in_yr9Non_Global)
	ren memb_in_yr9* *
	foreach var in Global Non_Global All {
		summarize `var'
		gen `var'_N = r(N)
	}
	collapse (mean) Global* Non_Global* All*, by(decade)
	
	local graphparams "scheme(`selected_scheme') outergap(-20) stack nolabel bargap(-20) yscale(titlegap(5)) legend(order(8 7 6 5 4 3 2 1)) graphregion(margin(tiny)) ysize(1) xsize(1.1)"

	foreach var in Global Non_Global All {
		summarize `var'_N
		local count=r(mean)
		if "`var'"=="Global" {
			local colorbar="bar(1, fcolor(green))"
			if "`color'" == "BW" {
				local colorbar="bar(1, fcolor(gs8))"
			}
		}
		if "`var'"=="Non_Global" {
			local colorbar="bar(1, fcolor(red))"
			if "`color'" == "BW" {
				local colorbar="bar(1, fcolor(gs12))"
			}
		}
		if "`var'"=="All" {
			local colorbar="bar(1, fcolor(blue))"
			if "`color'" == "BW" {
				local colorbar="bar(1, fcolor(gs0))"
			}
		}
		local caption="Average # of members in year `countyr' for `count' MEA Agreements (pre-`lastyr1')"
		noisily di "Graph Filename=AvgSize_MEAs_`var'_`color'.png Caption: `caption'"
		local title="`var' MEAs"
		graph bar `var', over(decade, gap(10) label(angle(70))) title("`title'") ytitle("Average # of Members") yscale(titlegap(5)) `colorbar' `graphparams'
		graph export "graphs\\AvgSize_MEAs_`var'_`color'.png", replace
	}
}
